netapp_ontap.models.analytics_info_by_accessed_time API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.analytics_info_by_accessed_time`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AnalyticsInfoByAccessedTimeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AnalyticsInfoByAccessedTime object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `bytes_used: AnalyticsHistogramByTime GET POST PATCH`

    Histogram maintained by file system analytics that associates data with specific periods of time.
    The properties of this object are three parallel lists as described here. For any index i, the ith element of each list corresponds to the same logical bucket within the histogram.